==> aws-java-sdk-iot-1.10.25-sources.jar: com/amazonaws/services/iot/model/transform/LoggingOptionsPayloadJsonMarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.iot.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.iot.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * LoggingOptionsPayloadMarshaller
 */
public class LoggingOptionsPayloadJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a JSONWriter
     */
    public void marshall(LoggingOptionsPayload loggingOptionsPayload,
            JSONWriter jsonWriter) {
        if (loggingOptionsPayload == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonWriter.object();

            if (loggingOptionsPayload.getRoleArn() != null) {
                jsonWriter.key("roleArn").value(
                        loggingOptionsPayload.getRoleArn());
            }

            if (loggingOptionsPayload.getLogLevel() != null) {
                jsonWriter.key("logLevel").value(
                        loggingOptionsPayload.getLogLevel());
            }

            jsonWriter.endObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static LoggingOptionsPayloadJsonMarshaller instance;

    public static LoggingOptionsPayloadJsonMarshaller getInstance() {
        if (instance == null)
            instance = new LoggingOptionsPayloadJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-iot-1.11.29-sources.jar: com/amazonaws/services/iot/model/transform/LoggingOptionsPayloadJsonMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.iot.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.iot.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * LoggingOptionsPayloadMarshaller
 */
public class LoggingOptionsPayloadJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(LoggingOptionsPayload loggingOptionsPayload,
            StructuredJsonGenerator jsonGenerator) {

        if (loggingOptionsPayload == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (loggingOptionsPayload.getRoleArn() != null) {
                jsonGenerator.writeFieldName("roleArn").writeValue(
                        loggingOptionsPayload.getRoleArn());
            }
            if (loggingOptionsPayload.getLogLevel() != null) {
                jsonGenerator.writeFieldName("logLevel").writeValue(
                        loggingOptionsPayload.getLogLevel());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static LoggingOptionsPayloadJsonMarshaller instance;

    public static LoggingOptionsPayloadJsonMarshaller getInstance() {
        if (instance == null)
            instance = new LoggingOptionsPayloadJsonMarshaller();
        return instance;
    }

}
